ebs_ipr_atom — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# ebs_ipr_atom

ElectronicBandStructure.ebs_ipr_atom()

  It returns the atom-resolved , pIPR:

  pIPR_j = frac{|c_j|^4}{(sum_i |c_i^2|)^2}

  Clearly, ( sum_j pIPR_j = IPR ).

  Mind: ( c_i ) is the wavefunction ( c(n,k)_i ), in pyprocar we already have density projections, ( c_i^2 ).

  THIS QUANTITY IS NOT READY FOR PLOTTING, please prefer self.ebs_ipr()

  Returns:

    ret (list float) – The IPR projections